##  Step 4: Start the Development Server
Once you've imported FactSheetsReport into the main module, you can start the development server. Run the following command:

```
npm start
```



A new tab opens in your browser displaying your custom report in the Reports section within your SAP LeanIX environment. If the tab doesn't open, the command provides a link that you can copy and then paste into the address bar of your browser.
The following image shows the outcome of the script used in this tutorial.
![Fact Sheets Report That Lists All Fact Sheets Available in a Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27469c827a441014b800c10ede97d733_LowRes.png)
Custom Report That Lists All Fact Sheets Available in a Workspace
